@@ -514,7 +514,7 @@ RequestNewModel <- function(project, blueprint, featurelist = NULL,
 #' In smart-sampled projects, `samplePct` and `trainingRowCount` are assumed to be in terms of rows
 #' of the minority class.
 #'
-#' Note : For datetime partitioned projects, use ``RequestFrozenDatetimeModel` instead
+#' Note : For datetime partitioned projects, use `RequestFrozenDatetimeModel` instead
 #'
 #' @inheritParams DeleteModel
 #' @param samplePct Numeric, specifying the percentage of the training
@@ -763,7 +763,12 @@ as.dataRobotDatetimeModel <- function(inList) {
                 "dataSelectionMethod",
                 "trainingInfo",
                 "holdoutScore",
-                "holdoutStatus")
+                "holdoutStatus",
+                "effectiveFeatureDerivationWindowStart",
+                "effectiveFeatureDerivationWindowEnd",
+                "forecastWindowStart",
+                "forecastWindowEnd",
+                "windowsBasisUnit")
   outList <- ApplySchema(inList, elements)
   class(outList) <- "dataRobotDatetimeModel"
   outList
@@ -778,60 +783,77 @@ as.dataRobotDatetimeModel <- function(inList) {
 #'
 #' @inheritParams DeleteProject
 #' @param modelId character. Unique alphanumeric identifier for the model of interest.
-#' @return An S3 object of class `dataRobotDatetimeModel', which is a list
+#' @return An S3 object of class `dataRobotDatetimeModel`, which is a list
 #' with the following components:
 #' \itemize{
-#'   \item featurelistId. Character string: unique alphanumeric identifier for the featurelist on
+#'   \item featurelistId character. Unique alphanumeric identifier for the featurelist on
 #'     which the model is based.
-#'   \item processes. Character vector with components describing preprocessing; may include
-#'     modelType.
-#'   \item featurelistName. Character string giving the name of the featurelist on which the model
-#'     is based.
-#'   \item projectId. Character string giving the unique alphanumeric identifier for the project.
-#'   \item samplePct. Numeric: percentage of the dataset used to form the training dataset for
+#'   \item processes character. Vector with components describing preprocessing; may include
+#'     `modelType`.
+#'   \item featurelistName character. The name of the featurelist on which the model is based.
+#'   \item projectId character. The unique alphanumeric identifier for the project.
+#'   \item samplePct numeric. Percentage of the dataset used to form the training dataset for
 #'     model fitting.
-#'   \item isFrozen. Logical : is model created with frozen tuning parameters.
-#'   \item modelType. Character string describing the model type.
-#'   \item metrics. List with one element for each valid metric associated with the model.
+#'   \item isFrozen logical. Is model created with frozen tuning parameters?
+#'   \item modelType character. A description of the model.
+#'   \item metrics list. List with one element for each valid metric associated with the model.
 #'     Each element is a list with elements for each possible evaluation type (holdout, validation,
 #'     and crossValidation).
-#'   \item modelCategory. Character string giving model category (e.g., blend, model).
-#'   \item blueprintId. Character string giving the unique DataRobot blueprint identifier on which
+#'   \item modelCategory character. The model category (e.g., blend, model).
+#'   \item blueprintId character. The unique DataRobot blueprint identifier on which
 #'     the model is based.
-#'   \item modelId. Character string giving the unique alphanumeric model identifier.
-#'   \item projectName. Character string: optional description of project defined by projectId.
-#'   \item projectTarget. Character string defining the target variable predicted by all models in
-#'     the project.
-#'   \item projectMetric. Character string defining the fitting metric optimized by all project
-#'     models.
-#'   \item trainingRowCount. Integer. The number of rows of the project dataset used in training
+#'   \item modelId character. The unique alphanumeric model identifier.
+#'   \item projectName character. Optional description of project defined by projectId.
+#'   \item projectTarget character. The target variable predicted by all models in the project.
+#'   \item projectMetric character. The fitting metric optimized by all project models.
+#'   \item trainingRowCount integer. The number of rows of the project dataset used in training
 #'     the model. In a datetime partitioned project, if specified, defines the number of
 #'      rows used to train the model and evaluate backtest scores; if unspecified, either
 #'      \code{trainingDuration} or \code{trainingStartDate} and \code{trainingEndDate} was used to
 #'      determine that instead.
-#'   \item trainingDuration. Character string or none only present for models in datetime
-#'     partitioned projects. If specified, a duration string specifying the duration spanned by the
-#'     data used to train the model and evaluate backtest scores.
-#'   \item trainingStartDate. Charcter string or none only present for frozen models in datetime
-#'     partitioned projects. If specified, the start date of the data used to train the model.
-#'   \item trainingEndDate. Charcter string or none only present for frozen models in datetime
-#'     partitioned projects. If specified, the end date of the data used to train the model.
-#'   \item backtests. list describes what data was used to fit each backtest, the score for the
+#'   \item trainingDuration character. Only present for models in datetime partitioned projects.
+#'      If specified, a duration string specifying the duration spanned by the data used to train
+#'      the model and evaluate backtest scores.
+#'   \item trainingStartDate character. Only present for frozen models in datetime partitioned
+#'      projects. If specified, the start date of the data used to train the model.
+#'   \item trainingEndDate character. Only present for frozen models in datetime partitioned
+#'      projects. If specified, the end date of the data used to train the model.
+#'   \item backtests list. What data was used to fit each backtest, the score for the
 #'     project metric, and why the backtest score is unavailable if it is not provided.
-#'   \item dataSelectionMethod. Character string which of trainingRowCount, trainingDuration,
+#'   \item dataSelectionMethod character. Which of trainingRowCount, trainingDuration,
 #'     or trainingStartDate and trainingEndDate were used to determine the data used to fit the
-#'     model. One of 'rowCount', 'duration', or 'selectedDateRange'.
-#'   \item trainingInfo. list describes which data was used to train on when scoring the holdout and
-#'     making predictions.
-#'   trainingInfo will have the following keys: `holdoutTrainingStartDate`,
+#'     model. One of "rowCount", "duration", or "selectedDateRange".
+#'   \item trainingInfo list. Which data was used to train on when scoring the holdout and
+#'     making predictions. trainingInfo will have the following keys: `holdoutTrainingStartDate`,
 #'     `holdoutTrainingDuration`, `holdoutTrainingRowCount`, `holdoutTrainingEndDate`,
 #'     `predictionTrainingStartDate`, `predictionTrainingDuration`,
 #'     `predictionTrainingRowCount`, `predictionTrainingEndDate`.  Start and end dates will be
 #'     datetime string, durations will be duration strings, and rows will be integers.
-#'   \item holdoutScore. numeric or none the score against the holdout, if available and the holdout
+#'   \item holdoutScore numeric. The score against the holdout, if available and the holdout
 #'     is unlocked, according to the project metric.
-#'   \item holdoutStatus. Character string the status of the holdout score, e.g. "COMPLETED",
+#'   \item holdoutStatus character. The status of the holdout score, e.g. "COMPLETED",
 #'     "HOLDOUT_BOUNDARIES_EXCEEDED".
+#'   \item effectiveFeatureDerivationWindowStart integer. Only available for time series projects.
+#'     How many timeUnits into the past relative to the forecast point the user needs to provide
+#'     history for at prediction time. This can differ from the `featureDerivationWindowStart` set
+#'     on the project due to the differencing method and period selected, or if the model is a time
+#'     series native model such as ARIMA. Will be a negative integer in time series projects and
+#'     `NULL` otherwise.
+#'   \item effectiveFeatureDerivationWindowEnd integer. Only available for time series projects.
+#'     How many timeUnits into the past relative to the forecast point the feature derivation window
+#'     should end. Will be a non-positive integer in time series projects and `NULL` otherwise.
+#'   \item forecastWindowStart integer. Only available for time series projects. How many timeUnits
+#'     into the future relative to the forecast point the forecast window should start. Note that
+#'     this field will be the same as what is shown in the project settings. Will be a non-negative
+#'     integer in time series projects and `NULL` otherwise.
+#"   \item forecastWindowEnd integer. Only available for time series projects. How many timeUnits
+#'     into the future relative to the forecast point the forecast window should end. Note that this
+#'     field will be the same as what is shown in the project settings. Will be a non-negative
+#'     integer in time series projects and `NULL` otherwise.
+#'   \item windowsBasisUnit character. Only available for time series projects. Indicates which unit
+#'     is the basis for the feature derivation window and the  forecast window. Note that this field
+#'     will be the same as what is shown in the project settings. In time series projects, will be
+#'     either the detected time unit or "ROW", and `NULL` otherwise.
 #' }
 #' @examples
 #' \dontrun{
